<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="118"/>
        <source>Deepin Movie</source>
        <translation>Filmy Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Program Filmy Deepin to dobrze zaprojektowany i pełen możliwości odtwarzacz filmów o prostym, pozbawionym obramowania stylu. Obsługuje zarówno lokalne, jak i sieciowe pliki mediów w najróżniejszych formatach wideo.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Nieprawidłowy katalog</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nie masz uprawnień do działań na tym katalogu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Automatycznie dodaj podobne pliki do odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Wyczyść listę odtwarzania przy wyjściu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Wyświetl podgląd filmu przy najeżdżeniu myszką</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Otwórz nowe okno odtwarzacza dla każdego odtwarzanego pliku</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Wstrzymaj przy minimalizacji</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Zapamiętaj pozycję odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Podstawowe</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Ramka/Dźwięk</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Odtwarzanie</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Napisy</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Styl czcionki</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Przywróć domyślne</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Otwórz następny</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Otwórz poprzedni</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Tryb mini</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Wycisz</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>volume down</source>
        <translation>Przycisz</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Volume up</source>
        <translation>Pogłośnij</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Speed up</source>
        <translation>Przyspiesz</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Speed down</source>
        <translation>Spowolnij</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Pause/Play</source>
        <translation>Wstrzymaj/Odtwórz</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Reset speed</source>
        <translation>Przywróć prędkość</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Rewind</source>
        <translation>Przewiń do tyłu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Forward</source>
        <translation>Przewiń do przodu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Burst screenshot</source>
        <translation>Seria zrzutów ekranu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Film screenshot</source>
        <translation>Zrzut ekranu z filmu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>0.5s backward</source>
        <translation>0,5 s do tyłu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>0.5s forward</source>
        <translation>0,5 s do przodu</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>Font Size</source>
        <translation>Rozmiar czcionki</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Prosimy wpisać adres URL:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="265"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>Motyw jasny</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Zawsze na wierzchu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="280"/>
        <source>Film info</source>
        <translation>Informacje o filmie</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Otwórz URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Otwórz CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Tryb mini</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Tryb odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Porządek odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Dowolne odtwarzanie</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Pojedyncze odtworzenie</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Pojedyncza pętla</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Pętla listy</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Ramka</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>Zgodnie z ruchem wskazówek zegara</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Przeciwnie do ruchu wskazówek zegara</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="148"/>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="151"/>
        <source>Channel</source>
        <translation>Kanał</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="154"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Left channel</source>
        <translation>Lewy kanał</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="156"/>
        <source>Right channel</source>
        <translation>Prawy kanał</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="162"/>
        <source>Track</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="172"/>
        <source>Subtitle</source>
        <translation>Napisy</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="173"/>
        <source>Load</source>
        <translation>Wczytaj</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="174"/>
        <source>Online Search</source>
        <translation>Wyszukiwanie online</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Select</source>
        <translation>Wybierz</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Hide</source>
        <translation>Ukryj</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Encodings</source>
        <translation>Kodowanie</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="254"/>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="255"/>
        <source>Film Screenshot</source>
        <translation>Zrzut ekranu z filmu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="256"/>
        <source>Burst Shooting</source>
        <translation>Seria ujęć</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="263"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="264"/>
        <source>Film Info</source>
        <translation>Informacje o filmie</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="278"/>
        <source>Clear playlist</source>
        <translation>Wyczyść listę odtwarzania</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="279"/>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>czas trwania: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>rozdzielczość: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>rozmiar: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>zapisz</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2279"/>
        <location filename="../common/mainwindow.cpp" line="2374"/>
        <source>Deepin Movie</source>
        <translation>Filmy Deepin</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load successfully</source>
        <translation>Pomyślnie wczytano</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1796"/>
        <source>Load failed</source>
        <translation>Błąd wczytywania</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1402"/>
        <source>No device found</source>
        <translation>Nie odnaleziono urządzenia</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1420"/>
        <source>Parse Failed</source>
        <translation>Błąd przetwarzania</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1427"/>
        <source>Open Folder</source>
        <translation>Otwórz katalog</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <location filename="../common/mainwindow.cpp" line="1459"/>
        <location filename="../common/mainwindow.cpp" line="1791"/>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1444"/>
        <location filename="../common/mainwindow.cpp" line="1461"/>
        <source>All videos (%1)</source>
        <translation>Wszystkie filmy (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1659"/>
        <source>Muted</source>
        <translation>Wyciszony</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1662"/>
        <location filename="../common/mainwindow.cpp" line="1674"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <location filename="../common/mainwindow.cpp" line="1691"/>
        <source>Volume: %1%</source>
        <translation>Głośność: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1756"/>
        <location filename="../common/mainwindow.cpp" line="1764"/>
        <source>Subtitle %1: %2s</source>
        <translation>Napisy %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>delayed</source>
        <translation>opóźnione</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <source>advanced</source>
        <translation>zaawansowane</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Speed: %1x</source>
        <translation>Prędkość: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1793"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>Pliki napisów (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1855"/>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1866"/>
        <source>Movie Screenshot</source>
        <translation>Zrzut ekranu z filmu</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1867"/>
        <source>Saved to</source>
        <translation>Zapisano do</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <location filename="../common/mainwindow.cpp" line="1952"/>
        <source>The screenshot is saved</source>
        <translation>Zrzut ekranu został zapisany</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1881"/>
        <source>The screenshot is failed to save</source>
        <translation>Błąd zapisu zrzutu ekranu</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2039"/>
        <location filename="../common/mainwindow.cpp" line="2728"/>
        <source>Invalid file: %1</source>
        <translation>Nieprawidłowy plik: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Rodzaj pliku:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Rozdzielczość:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Rozmiar pliku:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Czas trwania:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Ścieżka pliku:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1017"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1035"/>
        <source>[internal]</source>
        <translation>[wewnętrzny]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>Plik nie istnieje</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Napisy</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Odtwórz/Wstrzymaj</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Opuść tryb pełnoekranowy</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Wstrzymaj</translation>
    </message>
</context>
</TS>